@@ -2,7 +2,7 @@ from labelbase import Client as baseClient
 from labelbox import Client
 import pandas
 from concurrent.futures import ThreadPoolExecutor, as_completed
-from tqdm import tqdm
+from tqdm.autonotebook import tqdm
 import math
 
 def create_upload_dict(df:pandas.core.frame.DataFrame, lb_client:Client, base_client:baseClient, row_data_col:str, 
@@ -39,16 +39,23 @@ def create_upload_dict(df:pandas.core.frame.DataFrame, lb_client:Client, base_cl
             for index, row in df.iterrows():
                 futures.append(exc.submit(create_data_rows, lb_client, base_client, row, metadata_name_key_to_schema, metadata_schema_to_name_key, row_data_col, global_key_col, external_id_col, metadata_index, local_files, divider))
             if verbose:
-                print(f'Processing data rows...')        
-            for f in as_completed(futures):
-                res = f.result()
-                global_key_to_upload_dict[str(res["global_key"])] = res    
-                if verbose:
-                    x += 1
-                    percent_complete = math.ceil((x / len(df)*100))
-                    if percent_complete%1 == 0 and (percent_complete!=dupe_print):
-                        print(f'{str(percent_complete)}% complete')          
-                        dupe_print = percent_complete
+                print(f'Processing data rows...')
+                for f in tqdm(as_completed(futures)):
+                    res = f.result()
+                    global_key_to_upload_dict[str(res["global_key"])] = res    
+            else:
+                for f in as_completed(futures):
+                    res = f.result()
+                    global_key_to_upload_dict[str(res["global_key"])] = res                 
+#             for f in as_completed(futures):
+#                 res = f.result()
+#                 global_key_to_upload_dict[str(res["global_key"])] = res    
+#                 if verbose:
+#                     x += 1
+#                     percent_complete = math.ceil((x / len(df)*100))
+#                     if percent_complete%1 == 0 and (percent_complete!=dupe_print):
+#                         print(f'{str(percent_complete)}% complete')          
+#                         dupe_print = percent_complete
         if verbose:
             print(f'Generated upload list - {len(global_key_to_upload_dict)} data rows to upload')
         return True, global_key_to_upload_dict  
